@@ -1,6 +1,12 @@
 # This module provides a function to initialise the top-level logger
 import logging
 
+from SuperHelper.Core.Utils import PathLike
+
+__all__ = [
+    "setup_core_logger",
+]
+
 
 class TracebackInfoFilter(logging.Filter):
     """Clear or restore the exception on log records"""
@@ -20,7 +26,16 @@ class TracebackInfoFilter(logging.Filter):
         return True
 
 
-def initialise_core_logger(logging_path: str) -> logging.Logger:
+def setup_core_logger(logging_path: PathLike, debug: bool = False) -> logging.Logger:
+    """Sets up the core logger.
+
+    Args:
+        logging_path (PathLike): The path to the logging file.
+        debug (bool): Whether to print debugging message.
+
+    Returns:
+        A `logging.Logger` instance with name set to `SuperHelper`.
+    """
     logger = logging.getLogger("SuperHelper")
     logger.setLevel(logging.DEBUG)
     fh = logging.FileHandler(logging_path, mode="a+")
@@ -28,9 +43,15 @@ def initialise_core_logger(logging_path: str) -> logging.Logger:
     fh.setFormatter(logging.Formatter("[%(asctime)s](%(name)s) %(levelname)s: %(message)s"))
     fh.addFilter(TracebackInfoFilter(clear=False))
     ch = logging.StreamHandler()
-    ch.setLevel(logging.WARNING)
+    if debug:
+        ch.setLevel(logging.DEBUG)
+    else:
+        ch.setLevel(logging.WARNING)
     ch.setFormatter(logging.Formatter("%(levelname)s: %(message)s"))
-    ch.addFilter(TracebackInfoFilter())
+    if debug:
+        ch.addFilter(TracebackInfoFilter(clear=False))
+    else:
+        ch.addFilter(TracebackInfoFilter())
     logger.addHandler(fh)
     logger.addHandler(ch)
     return logger
